@@ -12,6 +12,7 @@ from opentelemetry import context as context_api
 from opentelemetry.sdk.trace import ReadableSpan, Span
 from opentelemetry.sdk.trace.export import SpanExporter, SpanExportResult
 
+from uipath._cli._evals.mocks.cache_manager import CacheManager
 from uipath._cli._evals.mocks.input_mocker import (
     generate_llm_input,
 )
@@ -25,7 +26,7 @@ from ..._events._events import (
     EvalSetRunUpdatedEvent,
     EvaluationEvents,
 )
-from ...eval.evaluators import BaseEvaluator, LegacyBaseEvaluator
+from ...eval.evaluators import BaseEvaluator
 from ...eval.models import EvaluationResult
 from ...eval.models.models import AgentExecution, EvalItemResult
 from .._runtime._contracts import (
@@ -43,11 +44,8 @@ from .._utils._eval_set import EvalHelpers
 from ..models.runtime_schema import Entrypoint
 from ._evaluator_factory import EvaluatorFactory
 from ._models._evaluation_set import (
-    AnyEvaluationItem,
-    AnyEvaluationSet,
-    AnyEvaluator,
     EvaluationItem,
-    LegacyEvaluationItem,
+    EvaluationSet,
 )
 from ._models._exceptions import EvaluationRuntimeException
 from ._models._output import (
@@ -60,6 +58,7 @@ from ._models._output import (
 )
 from ._span_collection import ExecutionSpanCollector
 from .mocks.mocks import (
+    cache_manager_context,
     clear_execution_context,
     set_execution_context,
 )
@@ -153,6 +152,7 @@ class UiPathEvalContext(UiPathRuntimeContext):
     eval_ids: Optional[List[str]] = None
     eval_set_run_id: Optional[str] = None
     verbose: bool = False
+    enable_mocker_cache: bool = False
 
 
 class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
@@ -204,41 +204,54 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
         event_bus = self.event_bus
 
-        # Load eval set (path is already resolved in cli_eval.py)
-        evaluation_set, _ = EvalHelpers.load_eval_set(
-            self.context.eval_set, self.context.eval_ids
-        )
-        evaluators = self._load_evaluators(evaluation_set)
+        # Create cache manager if enabled
+        if self.context.enable_mocker_cache:
+            cache_mgr = CacheManager()
+            cache_manager_context.set(cache_mgr)
 
-        await event_bus.publish(
-            EvaluationEvents.CREATE_EVAL_SET_RUN,
-            EvalSetRunCreatedEvent(
-                execution_id=self.execution_id,
-                entrypoint=self.context.entrypoint or "",
-                eval_set_run_id=self.context.eval_set_run_id,
-                eval_set_id=evaluation_set.id,
-                no_of_evals=len(evaluation_set.evaluations),
-                evaluators=evaluators,
-            ),
-        )
+        try:
+            # Load eval set (path is already resolved in cli_eval.py)
+            evaluation_set, _ = EvalHelpers.load_eval_set(
+                self.context.eval_set, self.context.eval_ids
+            )
+            evaluators = self._load_evaluators(evaluation_set)
 
-        # Check if parallel execution should be used
-        if (
-            self.context.workers
-            and self.context.workers > 1
-            and len(evaluation_set.evaluations) > 1
-        ):
-            eval_run_result_list = await self._execute_parallel(
-                evaluation_set, evaluators, event_bus, self.context.workers
+            await event_bus.publish(
+                EvaluationEvents.CREATE_EVAL_SET_RUN,
+                EvalSetRunCreatedEvent(
+                    execution_id=self.execution_id,
+                    entrypoint=self.context.entrypoint or "",
+                    eval_set_run_id=self.context.eval_set_run_id,
+                    eval_set_id=evaluation_set.id,
+                    no_of_evals=len(evaluation_set.evaluations),
+                    evaluators=evaluators,
+                ),
             )
-        else:
-            eval_run_result_list = await self._execute_sequential(
-                evaluation_set, evaluators, event_bus
+
+            # Check if parallel execution should be used
+            if (
+                self.context.workers
+                and self.context.workers > 1
+                and len(evaluation_set.evaluations) > 1
+            ):
+                eval_run_result_list = await self._execute_parallel(
+                    evaluation_set, evaluators, event_bus, self.context.workers
+                )
+            else:
+                eval_run_result_list = await self._execute_sequential(
+                    evaluation_set, evaluators, event_bus
+                )
+            results = UiPathEvalOutput(
+                evaluation_set_name=evaluation_set.name,
+                evaluation_set_results=eval_run_result_list,
             )
-        results = UiPathEvalOutput(
-            evaluation_set_name=evaluation_set.name,
-            evaluation_set_results=eval_run_result_list,
-        )
+        finally:
+            # Flush cache to disk at end of eval set and cleanup
+            if self.context.enable_mocker_cache:
+                cache_manager = cache_manager_context.get()
+                if cache_manager is not None:
+                    cache_manager.flush()
+                cache_manager_context.set(None)
 
         # Computing evaluator averages
         evaluator_averages: Dict[str, float] = defaultdict(float)
@@ -270,8 +283,8 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
     async def _execute_sequential(
         self,
-        evaluation_set: AnyEvaluationSet,
-        evaluators: List[AnyEvaluator],
+        evaluation_set: EvaluationSet,
+        evaluators: List[BaseEvaluator[Any, Any, Any]],
         event_bus: EventBus,
     ) -> List[EvaluationRunResult]:
         all_eval_run_result: list[EvaluationRunResult] = []
@@ -285,13 +298,13 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
     async def _execute_parallel(
         self,
-        evaluation_set: AnyEvaluationSet,
-        evaluators: List[AnyEvaluator],
+        evaluation_set: EvaluationSet,
+        evaluators: List[BaseEvaluator[Any, Any, Any]],
         event_bus: EventBus,
         workers: int,
     ) -> List[EvaluationRunResult]:
         # Create a queue with max concurrency
-        queue: asyncio.Queue[tuple[int, AnyEvaluationItem]] = asyncio.Queue(
+        queue: asyncio.Queue[tuple[int, EvaluationItem]] = asyncio.Queue(
             maxsize=workers
         )
 
@@ -301,7 +314,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         # Producer task to fill the queue
         async def producer() -> None:
             for index, eval_item in enumerate(evaluation_set.evaluations):
-                await queue.put((index, eval_item))  # type: ignore[arg-type]
+                await queue.put((index, eval_item))
             # Signal completion by putting None markers
             for _ in range(workers):
                 await queue.put(None)  # type: ignore
@@ -343,8 +356,8 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
     async def _execute_eval(
         self,
-        eval_item: AnyEvaluationItem,
-        evaluators: List[AnyEvaluator],
+        eval_item: EvaluationItem,
+        evaluators: List[BaseEvaluator[Any, Any, Any]],
         event_bus: EventBus,
     ) -> EvaluationRunResult:
         # Generate LLM-based input if input_mocking_strategy is defined
@@ -416,41 +429,21 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
             evaluation_item_results: list[EvalItemResult] = []
 
             for evaluator in evaluators:
-                # Determine which evaluator method to use based on evaluation set/item type
-                evaluation_result: Optional[EvaluationResult] = None
-
-                match eval_item:
-                    case LegacyEvaluationItem():
-                        # Legacy evaluation - use run_legacy_evaluator
-                        evaluation_result = await self.run_legacy_evaluator(
-                            evaluator=evaluator,  # type: ignore
-                            execution_output=agent_execution_output,
-                            eval_item=eval_item,
-                        )
-                    case EvaluationItem() if (
-                        evaluator.id in eval_item.evaluation_criterias
-                    ):
-                        # New evaluation with criteria
-                        evaluation_criteria = eval_item.evaluation_criterias[
-                            evaluator.id
-                        ]
-
-                        evaluation_result = await self.run_evaluator(
-                            evaluator=evaluator,  # type: ignore
-                            execution_output=agent_execution_output,
-                            eval_item=eval_item,
-                            evaluation_criteria=evaluator.evaluation_criteria_type(  # type: ignore
-                                **evaluation_criteria
-                            )
-                            if evaluation_criteria
-                            else evaluator.evaluator_config.default_evaluation_criteria,  # type: ignore
-                        )
-                    case _:
-                        # Skip if evaluator not in evaluation criteria
-                        continue
-
-                if evaluation_result is None:
+                if evaluator.id not in eval_item.evaluation_criterias:
+                    # Skip!
                     continue
+                evaluation_criteria = eval_item.evaluation_criterias[evaluator.id]
+
+                evaluation_result = await self.run_evaluator(
+                    evaluator=evaluator,
+                    execution_output=agent_execution_output,
+                    eval_item=eval_item,
+                    evaluation_criteria=evaluator.evaluation_criteria_type(
+                        **evaluation_criteria
+                    )
+                    if evaluation_criteria
+                    else evaluator.evaluator_config.default_evaluation_criteria,
+                )
 
                 dto_result = EvaluationResultDto.from_evaluation_result(
                     evaluation_result
@@ -527,8 +520,8 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         return evaluation_run_results
 
     async def _generate_input_for_eval(
-        self, eval_item: AnyEvaluationItem
-    ) -> AnyEvaluationItem:
+        self, eval_item: EvaluationItem
+    ) -> EvaluationItem:
         """Use LLM to generate a mock input for an evaluation item."""
         generated_input = await generate_llm_input(
             eval_item, (await self.get_entrypoint()).input
@@ -549,7 +542,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         return spans, logs
 
     async def execute_runtime(
-        self, eval_item: AnyEvaluationItem, execution_id: str
+        self, eval_item: EvaluationItem, execution_id: str
     ) -> UiPathEvalRunExecutionOutput:
         context_args = self.context.model_dump()
         context_args["execution_id"] = execution_id
@@ -622,32 +615,25 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
         return result
 
-    async def run_legacy_evaluator(
-        self,
-        evaluator: LegacyBaseEvaluator[Any],
-        execution_output: UiPathEvalRunExecutionOutput,
-        eval_item: LegacyEvaluationItem,
-    ) -> EvaluationResult:
-        agent_execution = AgentExecution(
-            agent_input=eval_item.inputs,
-            agent_output=execution_output.result.output or {},
-            agent_trace=execution_output.spans,
-            expected_agent_behavior=eval_item.expected_agent_behavior,
-        )
-
-        result = await evaluator.evaluate(
-            agent_execution=agent_execution,
-            # at the moment evaluation_criteria is always the expected output
-            evaluation_criteria=eval_item.expected_output,
-        )
-
-        return result
-
-    def _load_evaluators(self, evaluation_set: AnyEvaluationSet) -> list[AnyEvaluator]:
+    def _load_evaluators(
+        self, evaluation_set: EvaluationSet
+    ) -> list[BaseEvaluator[Any, Any, Any]]:
         """Load evaluators referenced by the evaluation set."""
         evaluators = []
         evaluators_dir = Path(self.context.eval_set).parent.parent / "evaluators"  # type: ignore
-        evaluator_refs = set(evaluation_set.evaluator_refs)
+
+        # If evaluatorConfigs is specified, use that (new field with weights)
+        # Otherwise, fall back to evaluatorRefs (old field without weights)
+        if (
+            hasattr(evaluation_set, "evaluator_configs")
+            and evaluation_set.evaluator_configs
+        ):
+            # Use new evaluatorConfigs field - supports weights
+            evaluator_ref_ids = {ref.ref for ref in evaluation_set.evaluator_configs}
+        else:
+            # Fall back to old evaluatorRefs field - plain strings
+            evaluator_ref_ids = set(evaluation_set.evaluator_refs)
+
         found_evaluator_ids = set()
 
         for file in evaluators_dir.glob("*.json"):
@@ -662,7 +648,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
             try:
                 evaluator_id = data.get("id")
-                if evaluator_id in evaluator_refs:
+                if evaluator_id in evaluator_ref_ids:
                     evaluator = EvaluatorFactory.create_evaluator(data)
                     evaluators.append(evaluator)
                     found_evaluator_ids.add(evaluator_id)
@@ -672,7 +658,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
                     f"Please verify the evaluator configuration."
                 ) from e
 
-        missing_evaluators = evaluator_refs - found_evaluator_ids
+        missing_evaluators = evaluator_ref_ids - found_evaluator_ids
         if missing_evaluators:
             raise ValueError(
                 f"Could not find the following evaluators: {missing_evaluators}"
