@@ -10,18 +10,17 @@ import click
 
 from ..._config import UiPathConfig
 from ...models.exceptions import EnrichedException
+from .._utils._common import get_claim_from_token
 from .._utils._console import ConsoleLogger
 from .._utils._constants import (
     AGENT_INITIAL_CODE_VERSION,
     AGENT_STORAGE_VERSION,
     AGENT_TARGET_RUNTIME,
     AGENT_VERSION,
-    special_files,
 )
 from .._utils._project_files import (  # type: ignore
     FileInfo,
     InteractiveConflictHandler,
-    Severity,
     UpdateEvent,
     compute_normalized_hash,
     files_to_include,
@@ -165,17 +164,6 @@ class SwFileHandler:
         updates: list[UpdateEvent] = []
 
         for local_file in local_files:
-            if local_file.file_name in special_files:
-                updates.append(
-                    UpdateEvent(
-                        file_path=local_file.file_path,
-                        status="skipped",
-                        message=f"Skipped '{local_file.file_name}' as it is conflicting with a project configuration file.",
-                        severity=Severity.WARNING,
-                    )
-                )
-                continue
-
             if not os.path.exists(local_file.file_path):
                 logger.info(f"File not found: '{local_file.file_path}'")
                 continue
@@ -531,20 +519,13 @@ class SwFileHandler:
 
         def get_author_from_token_or_toml() -> str:
             """Get author from JWT token or fall back to pyproject.toml."""
-            import jwt
-
-            token = os.getenv("UIPATH_ACCESS_TOKEN")
-            if token:
-                try:
-                    decoded_token = jwt.decode(
-                        token, options={"verify_signature": False}
-                    )
-                    preferred_username = decoded_token.get("preferred_username")
-                    if preferred_username:
-                        return preferred_username
-                except Exception:
-                    # If JWT decoding fails, fall back to toml
-                    pass
+            try:
+                preferred_username = get_claim_from_token("preferred_username")
+                if preferred_username:
+                    return preferred_username
+            except Exception:
+                # fallback to toml
+                pass
 
             toml_data = read_toml_project(
                 os.path.join(self.directory, "pyproject.toml")
