@@ -5,8 +5,6 @@ from pathlib import Path
 from typing import Any, Awaitable, Callable, Dict, List, Optional, Set, Tuple, Union
 from uuid import UUID
 
-from httpx._types import FileContent
-
 from .._config import Config
 from .._execution_context import ExecutionContext
 from .._folder_context import FolderContext
@@ -17,11 +15,12 @@ from ..models.documents import (
     ClassificationResult,
     ExtractionResponse,
     ExtractionResponseIXP,
+    FileContent,
     ProjectType,
-    ValidatedResult,
-    ValidationAction,
+    ValidateClassificationAction,
+    ValidateExtractionAction,
 )
-from ..tracing._traced import traced
+from ..tracing import traced
 from ._base_service import BaseService
 
 POLLING_INTERVAL = 2  # seconds
@@ -53,6 +52,7 @@ def _exactly_one_must_be_provided(**kwargs: Any) -> None:
 
 
 def _validate_extract_params_and_get_project_type(
+    tag: Optional[str],
     project_name: Optional[str],
     file: Optional[FileContent],
     file_path: Optional[str],
@@ -61,13 +61,14 @@ def _validate_extract_params_and_get_project_type(
     document_type_name: Optional[str],
 ) -> ProjectType:
     if _is_provided(project_name):
-        _must_be_provided(project_type=project_type)
+        _must_be_provided(project_type=project_type, tag=tag)
         _exactly_one_must_be_provided(file=file, file_path=file_path)
         _must_not_be_provided(classification_result=classification_result)
         if project_type == ProjectType.MODERN:
             _must_be_provided(document_type_name=document_type_name)
     else:
         _must_not_be_provided(
+            tag=tag,
             project_name=project_name,
             project_type=project_type,
             file=file,
@@ -198,13 +199,13 @@ class DocumentsService(FolderContext, BaseService):
 
         return document_id
 
-    def _get_project_id_and_validate_tag(
+    def _get_project_id_and_tag(
         self,
-        tag: str,
+        tag: Optional[str],
         project_name: Optional[str],
         project_type: Optional[ProjectType],
         classification_result: Optional[ClassificationResult],
-    ) -> str:
+    ) -> Tuple[str, str]:
         if project_name is not None:
             project_id = self._get_project_id_by_name(
                 project_name,
@@ -212,6 +213,7 @@ class DocumentsService(FolderContext, BaseService):
             )
         else:
             project_id = classification_result.project_id  # type: ignore
+            tag = classification_result.tag  # type: ignore
 
         tags = self._get_project_tags(project_id)
         if tag not in tags:
@@ -219,15 +221,15 @@ class DocumentsService(FolderContext, BaseService):
                 f"Tag '{tag}' not found in project '{project_name}'. Available tags: {tags}"
             )
 
-        return project_id
+        return project_id, tag
 
-    async def _get_project_id_and_validate_tag_async(
+    async def _get_project_id_and_tag_async(
         self,
-        tag: str,
+        tag: Optional[str],
         project_name: Optional[str],
         project_type: Optional[ProjectType],
         classification_result: Optional[ClassificationResult],
-    ) -> str:
+    ) -> Tuple[str, str]:
         if project_name is not None:
             project_id = await self._get_project_id_by_name_async(
                 project_name,
@@ -235,6 +237,7 @@ class DocumentsService(FolderContext, BaseService):
             )
         else:
             project_id = classification_result.project_id  # type: ignore
+            tag = classification_result.tag  # type: ignore
 
         tags = await self._get_project_tags_async(project_id)
         if tag not in tags:
@@ -242,7 +245,7 @@ class DocumentsService(FolderContext, BaseService):
                 f"Tag '{tag}' not found in project '{project_name}'. Available tags: {tags}"
             )
 
-        return project_id
+        return project_id, tag
 
     def _start_digitization(
         self,
@@ -512,6 +515,7 @@ class DocumentsService(FolderContext, BaseService):
         extraction_response["projectId"] = project_id
         extraction_response["tag"] = tag
         extraction_response["documentTypeId"] = document_type_id
+        extraction_response["projectType"] = project_type
 
         if project_type == ProjectType.IXP:
             return ExtractionResponseIXP.model_validate(extraction_response)
@@ -552,6 +556,7 @@ class DocumentsService(FolderContext, BaseService):
         extraction_response["projectId"] = project_id
         extraction_response["tag"] = tag
         extraction_response["documentTypeId"] = document_type_id
+        extraction_response["projectType"] = project_type
 
         if project_type == ProjectType.IXP:
             return ExtractionResponseIXP.model_validate(extraction_response)
@@ -620,6 +625,7 @@ class DocumentsService(FolderContext, BaseService):
         )
         for classification_result in classification_response["classificationResults"]:
             classification_result["ProjectId"] = project_id
+            classification_result["Tag"] = tag
 
         return ClassificationResponse.model_validate(
             classification_response
@@ -655,6 +661,7 @@ class DocumentsService(FolderContext, BaseService):
         )
         for classification_result in classification_response["classificationResults"]:
             classification_result["ProjectId"] = project_id
+            classification_result["Tag"] = tag
 
         return ClassificationResponse.model_validate(
             classification_response
@@ -694,7 +701,7 @@ class DocumentsService(FolderContext, BaseService):
         """
         _exactly_one_must_be_provided(file=file, file_path=file_path)
 
-        project_id = self._get_project_id_and_validate_tag(
+        project_id, tag = self._get_project_id_and_tag(
             tag=tag,
             project_name=project_name,
             project_type=ProjectType.MODERN,
@@ -731,7 +738,7 @@ class DocumentsService(FolderContext, BaseService):
         """Asynchronously version of the [`classify`][uipath._services.documents_service.DocumentsService.classify] method."""
         _exactly_one_must_be_provided(file=file, file_path=file_path)
 
-        project_id = await self._get_project_id_and_validate_tag_async(
+        project_id, tag = await self._get_project_id_and_tag_async(
             tag=tag,
             project_name=project_name,
             project_type=ProjectType.MODERN,
@@ -760,7 +767,7 @@ class DocumentsService(FolderContext, BaseService):
     @traced(name="documents_extract", run_type="uipath")
     def extract(
         self,
-        tag: str,
+        tag: Optional[str] = None,
         project_name: Optional[str] = None,
         file: Optional[FileContent] = None,
         file_path: Optional[str] = None,
@@ -772,17 +779,18 @@ class DocumentsService(FolderContext, BaseService):
 
         Args:
             project_name (str, optional): Name of the [IXP](https://docs.uipath.com/ixp/automation-cloud/latest/overview/managing-projects#creating-a-new-project)/[DU Modern](https://docs.uipath.com/document-understanding/automation-cloud/latest/user-guide/about-document-understanding) project. Must be provided if `classification_result` is not provided.
-            tag (str): Tag of the published project version.
+            tag (str): Tag of the published project version. Must be provided if `classification_result` is not provided.
             file (FileContent, optional): The document file to be processed. Must be provided if `classification_result` is not provided.
             file_path (str, optional): Path to the document file to be processed. Must be provided if `classification_result` is not provided.
             project_type (ProjectType, optional): Type of the project. Must be provided if `project_name` is provided.
             document_type_name (str, optional): Document type name associated with the extractor to be used for extraction. Required if `project_type` is `ProjectType.MODERN` and `project_name` is provided.
+            classification_result (ClassificationResult, optional): The classification result obtained from a previous classification step. If provided, `project_name`, `project_type`, `file`, `file_path`, and `document_type_name` must not be provided.
 
         Note:
             Either `file` or `file_path` must be provided, but not both.
 
         Returns:
-            ExtractionResponse: The extraction result containing predicted data.
+            Union[ExtractionResponse, ExtractionResponseIXP]: The extraction response containing the extracted data.
 
         Examples:
             IXP projects:
@@ -817,12 +825,12 @@ class DocumentsService(FolderContext, BaseService):
                 )
 
             extraction_result = uipath.documents.extract(
-                tag="Production",
                 classification_result=max(classification_results, key=lambda result: result.confidence),
             )
             ```
         """
         project_type = _validate_extract_params_and_get_project_type(
+            tag=tag,
             project_name=project_name,
             file=file,
             file_path=file_path,
@@ -831,7 +839,7 @@ class DocumentsService(FolderContext, BaseService):
             document_type_name=document_type_name,
         )
 
-        project_id = self._get_project_id_and_validate_tag(
+        project_id, tag = self._get_project_id_and_tag(
             tag=tag,
             project_name=project_name,
             project_type=project_type,
@@ -870,7 +878,7 @@ class DocumentsService(FolderContext, BaseService):
     @traced(name="documents_extract_async", run_type="uipath")
     async def extract_async(
         self,
-        tag: str,
+        tag: Optional[str] = None,
         project_name: Optional[str] = None,
         file: Optional[FileContent] = None,
         file_path: Optional[str] = None,
@@ -880,6 +888,7 @@ class DocumentsService(FolderContext, BaseService):
     ) -> Union[ExtractionResponse, ExtractionResponseIXP]:
         """Asynchronously version of the [`extract`][uipath._services.documents_service.DocumentsService.extract] method."""
         project_type = _validate_extract_params_and_get_project_type(
+            tag=tag,
             project_name=project_name,
             file=file,
             file_path=file_path,
@@ -888,7 +897,7 @@ class DocumentsService(FolderContext, BaseService):
             document_type_name=document_type_name,
         )
 
-        project_id = await self._get_project_id_and_validate_tag_async(
+        project_id, tag = await self._get_project_id_and_tag_async(
             tag=tag,
             project_name=project_name,
             project_type=project_type,
@@ -924,7 +933,75 @@ class DocumentsService(FolderContext, BaseService):
             project_type=project_type,
         )
 
-    def _start_validation(
+    def _start_classification_validation(
+        self,
+        project_id: str,
+        tag: str,
+        action_title: str,
+        action_priority: ActionPriority,
+        action_catalog: str,
+        action_folder: str,
+        storage_bucket_name: str,
+        storage_bucket_directory_path: str,
+        classification_results: List[ClassificationResult],
+    ) -> str:
+        return self.request(
+            "POST",
+            url=Endpoint(
+                f"/du_/api/framework/projects/{project_id}/{tag}/classifiers/validation/start"
+            ),
+            params={"api-version": 1.1},
+            headers=self._get_common_headers(),
+            json={
+                "classificationResults": [
+                    cr.model_dump() for cr in classification_results
+                ],
+                "documentId": classification_results[0].document_id,
+                "actionTitle": action_title,
+                "actionPriority": action_priority,
+                "actionCatalog": action_catalog,
+                "actionFolder": action_folder,
+                "storageBucketName": storage_bucket_name,
+                "storageBucketDirectoryPath": storage_bucket_directory_path,
+            },
+        ).json()["operationId"]
+
+    async def _start_classification_validation_async(
+        self,
+        project_id: str,
+        tag: str,
+        action_title: str,
+        action_priority: ActionPriority,
+        action_catalog: str,
+        action_folder: str,
+        storage_bucket_name: str,
+        storage_bucket_directory_path: str,
+        classification_results: List[ClassificationResult],
+    ) -> str:
+        return (
+            await self.request_async(
+                "POST",
+                url=Endpoint(
+                    f"/du_/api/framework/projects/{project_id}/{tag}/classifiers/validation/start"
+                ),
+                params={"api-version": 1.1},
+                headers=self._get_common_headers(),
+                json={
+                    "classificationResults": [
+                        cr.model_dump() for cr in classification_results
+                    ],
+                    "documentId": classification_results[0].document_id,
+                    "actionTitle": action_title,
+                    "actionPriority": action_priority,
+                    "actionCatalog": action_catalog,
+                    "actionFolder": action_folder,
+                    "storageBucketName": storage_bucket_name,
+                    "storageBucketDirectoryPath": storage_bucket_directory_path,
+                },
+            )
+        ).json()["operationId"]
+
+    def _start_extraction_validation(
         self,
         project_id: str,
         tag: str,
@@ -957,7 +1034,7 @@ class DocumentsService(FolderContext, BaseService):
             },
         ).json()["operationId"]
 
-    async def _start_validation_async(
+    async def _start_extraction_validation_async(
         self,
         project_id: str,
         tag: str,
@@ -992,7 +1069,33 @@ class DocumentsService(FolderContext, BaseService):
             )
         ).json()["operationId"]
 
-    def _get_validation_result(
+    def _get_classification_validation_result(
+        self, project_id: str, tag: str, operation_id: str
+    ) -> Dict:  # type: ignore
+        return self.request(
+            method="GET",
+            url=Endpoint(
+                f"/du_/api/framework/projects/{project_id}/{tag}/classifiers/validation/result/{operation_id}"
+            ),
+            params={"api-version": 1.1},
+            headers=self._get_common_headers(),
+        ).json()
+
+    async def _get_classification_validation_result_async(
+        self, project_id: str, tag: str, operation_id: str
+    ) -> Dict:  # type: ignore
+        return (
+            await self.request_async(
+                method="GET",
+                url=Endpoint(
+                    f"/du_/api/framework/projects/{project_id}/{tag}/classifiers/validation/result/{operation_id}"
+                ),
+                params={"api-version": 1.1},
+                headers=self._get_common_headers(),
+            )
+        ).json()
+
+    def _get_extraction_validation_result(
         self, project_id: str, tag: str, document_type_id: str, operation_id: str
     ) -> Dict:  # type: ignore
         return self.request(
@@ -1004,7 +1107,7 @@ class DocumentsService(FolderContext, BaseService):
             headers=self._get_common_headers(),
         ).json()
 
-    async def _get_validation_result_async(
+    async def _get_extraction_validation_result_async(
         self, project_id: str, tag: str, document_type_id: str, operation_id: str
     ) -> Dict:  # type: ignore
         return (
@@ -1018,11 +1121,76 @@ class DocumentsService(FolderContext, BaseService):
             )
         ).json()
 
-    def _wait_for_create_validation_action(
-        self, project_id: str, tag: str, document_type_id: str, operation_id: str
-    ) -> ValidationAction:
+    def _wait_for_create_validate_classification_action(
+        self,
+        project_id: str,
+        tag: str,
+        operation_id: str,
+    ) -> ValidateClassificationAction:
         def result_getter() -> Tuple[Any, Optional[Any], Optional[Any]]:
-            result = self._get_validation_result(
+            result = self._get_classification_validation_result(
+                project_id=project_id,
+                tag=tag,
+                operation_id=operation_id,
+            )
+            return (
+                result["status"],
+                result.get("error", None),
+                result.get("result", None),
+            )
+
+        response = self._wait_for_operation(
+            result_getter=result_getter,
+            wait_statuses=["NotStarted", "Running"],
+            success_status="Succeeded",
+        )
+
+        response["projectId"] = project_id
+        response["projectType"] = ProjectType.MODERN
+        response["tag"] = tag
+        response["operationId"] = operation_id
+        return ValidateClassificationAction.model_validate(response)
+
+    async def _wait_for_create_validate_classification_action_async(
+        self,
+        project_id: str,
+        tag: str,
+        operation_id: str,
+    ) -> ValidateClassificationAction:
+        async def result_getter() -> Tuple[Any, Optional[Any], Optional[Any]]:
+            result = await self._get_classification_validation_result_async(
+                project_id=project_id,
+                tag=tag,
+                operation_id=operation_id,
+            )
+            return (
+                result["status"],
+                result.get("error", None),
+                result.get("result", None),
+            )
+
+        response = await self._wait_for_operation_async(
+            result_getter=result_getter,
+            wait_statuses=["NotStarted", "Running"],
+            success_status="Succeeded",
+        )
+
+        response["projectId"] = project_id
+        response["projectType"] = ProjectType.MODERN
+        response["tag"] = tag
+        response["operationId"] = operation_id
+        return ValidateClassificationAction.model_validate(response)
+
+    def _wait_for_create_validate_extraction_action(
+        self,
+        project_id: str,
+        project_type: ProjectType,
+        tag: str,
+        document_type_id: str,
+        operation_id: str,
+    ) -> ValidateExtractionAction:
+        def result_getter() -> Tuple[Any, Optional[Any], Optional[Any]]:
+            result = self._get_extraction_validation_result(
                 project_id=project_id,
                 tag=tag,
                 document_type_id=document_type_id,
@@ -1041,16 +1209,22 @@ class DocumentsService(FolderContext, BaseService):
         )
 
         response["projectId"] = project_id
+        response["projectType"] = project_type
         response["tag"] = tag
         response["documentTypeId"] = document_type_id
         response["operationId"] = operation_id
-        return ValidationAction.model_validate(response)
+        return ValidateExtractionAction.model_validate(response)
 
-    async def _wait_for_create_validation_action_async(
-        self, project_id: str, tag: str, document_type_id: str, operation_id: str
-    ) -> ValidationAction:
+    async def _wait_for_create_validate_extraction_action_async(
+        self,
+        project_id: str,
+        project_type: ProjectType,
+        tag: str,
+        document_type_id: str,
+        operation_id: str,
+    ) -> ValidateExtractionAction:
         async def result_getter_async() -> Tuple[Any, Optional[Any], Optional[Any]]:
-            result = await self._get_validation_result_async(
+            result = await self._get_extraction_validation_result_async(
                 project_id=project_id,
                 tag=tag,
                 document_type_id=document_type_id,
@@ -1069,13 +1243,106 @@ class DocumentsService(FolderContext, BaseService):
         )
 
         response["projectId"] = project_id
+        response["projectType"] = project_type
         response["tag"] = tag
         response["documentTypeId"] = document_type_id
         response["operationId"] = operation_id
-        return ValidationAction.model_validate(response)
+        return ValidateExtractionAction.model_validate(response)
 
-    @traced(name="documents_create_validation_action", run_type="uipath")
-    def create_validation_action(
+    @traced(name="documents_create_validate_classification_action", run_type="uipath")
+    def create_validate_classification_action(
+        self,
+        action_title: str,
+        action_priority: ActionPriority,
+        action_catalog: str,
+        action_folder: str,
+        storage_bucket_name: str,
+        storage_bucket_directory_path: str,
+        classification_results: List[ClassificationResult],
+    ) -> ValidateClassificationAction:
+        """Create a validate classification action for a document based on the classification results. More details about validation actions can be found in the [official documentation](https://docs.uipath.com/ixp/automation-cloud/latest/user-guide/validating-classifications).
+
+        Args:
+            action_title (str): Title of the action.
+            action_priority (ActionPriority): Priority of the action.
+            action_catalog (str): Catalog of the action.
+            action_folder (str): Folder of the action.
+            storage_bucket_name (str): Name of the storage bucket.
+            storage_bucket_directory_path (str): Directory path in the storage bucket.
+            classification_results (List[ClassificationResult]): The classification results to be validated, typically obtained from the [`classify`][uipath._services.documents_service.DocumentsService.classify] method.
+
+        Returns:
+            ValidateClassificationAction: The created validate classification action.
+
+        Examples:
+            ```python
+            validation_action = service.create_validate_classification_action(
+                action_title="Test Validation Action",
+                action_priority=ActionPriority.MEDIUM,
+                action_catalog="default_du_actions",
+                action_folder="Shared",
+                storage_bucket_name="du_storage_bucket",
+                storage_bucket_directory_path="TestDirectory",
+                classification_results=classification_results,
+            )
+            ```
+        """
+        if not classification_results:
+            raise ValueError("`classification_results` must not be empty")
+
+        operation_id = self._start_classification_validation(
+            project_id=classification_results[0].project_id,
+            tag=classification_results[0].tag,
+            action_title=action_title,
+            action_priority=action_priority,
+            action_catalog=action_catalog,
+            action_folder=action_folder,
+            storage_bucket_name=storage_bucket_name,
+            storage_bucket_directory_path=storage_bucket_directory_path,
+            classification_results=classification_results,
+        )
+
+        return self._wait_for_create_validate_classification_action(
+            project_id=classification_results[0].project_id,
+            tag=classification_results[0].tag,
+            operation_id=operation_id,
+        )
+
+    @traced(name="documents_create_validate_classification_action", run_type="uipath")
+    async def create_validate_classification_action_async(
+        self,
+        action_title: str,
+        action_priority: ActionPriority,
+        action_catalog: str,
+        action_folder: str,
+        storage_bucket_name: str,
+        storage_bucket_directory_path: str,
+        classification_results: List[ClassificationResult],
+    ) -> ValidateClassificationAction:
+        """Asynchronous version of the [`create_validation_action`][uipath._services.documents_service.DocumentsService.create_validate_classification_action] method."""
+        if not classification_results:
+            raise ValueError("`classification_results` must not be empty")
+
+        operation_id = await self._start_classification_validation_async(
+            project_id=classification_results[0].project_id,
+            tag=classification_results[0].tag,
+            action_title=action_title,
+            action_priority=action_priority,
+            action_catalog=action_catalog,
+            action_folder=action_folder,
+            storage_bucket_name=storage_bucket_name,
+            storage_bucket_directory_path=storage_bucket_directory_path,
+            classification_results=classification_results,
+        )
+
+        return await self._wait_for_create_validate_classification_action_async(
+            project_id=classification_results[0].project_id,
+            tag=classification_results[0].tag,
+            operation_id=operation_id,
+        )
+
+    @traced(name="documents_create_validate_extraction_action", run_type="uipath")
+    def create_validate_extraction_action(
         self,
         action_title: str,
         action_priority: ActionPriority,
@@ -1084,8 +1351,8 @@ class DocumentsService(FolderContext, BaseService):
         storage_bucket_name: str,
         storage_bucket_directory_path: str,
         extraction_response: ExtractionResponse,
-    ) -> ValidationAction:
-        """Create a validation action for a document based on the extraction response. More details about validation actions can be found in the [official documentation](https://docs.uipath.com/ixp/automation-cloud/latest/user-guide/validating-extractions).
+    ) -> ValidateExtractionAction:
+        """Create a validate extraction action for a document based on the extraction response. More details about validation actions can be found in the [official documentation](https://docs.uipath.com/ixp/automation-cloud/latest/user-guide/validating-extractions).
 
         Args:
             action_title (str): Title of the action.
@@ -1097,22 +1364,22 @@ class DocumentsService(FolderContext, BaseService):
             extraction_response (ExtractionResponse): The extraction result to be validated, typically obtained from the [`extract`][uipath._services.documents_service.DocumentsService.extract] method.
 
         Returns:
-            ValidationAction: The created validation action.
+            ValidateClassificationAction: The created validation action.
 
         Examples:
             ```python
-            validation_action = service.create_validation_action(
+            validation_action = service.create_validate_extraction_action(
                 action_title="Test Validation Action",
                 action_priority=ActionPriority.MEDIUM,
                 action_catalog="default_du_actions",
                 action_folder="Shared",
-                storage_bucket_name="TestBucket",
+                storage_bucket_name="du_storage_bucket",
                 storage_bucket_directory_path="TestDirectory",
                 extraction_response=extraction_response,
             )
             ```
         """
-        operation_id = self._start_validation(
+        operation_id = self._start_extraction_validation(
             project_id=extraction_response.project_id,
             tag=extraction_response.tag,
             document_type_id=extraction_response.document_type_id,
@@ -1125,15 +1392,16 @@ class DocumentsService(FolderContext, BaseService):
             extraction_response=extraction_response,
         )
 
-        return self._wait_for_create_validation_action(
+        return self._wait_for_create_validate_extraction_action(
             project_id=extraction_response.project_id,
+            project_type=extraction_response.project_type,
             tag=extraction_response.tag,
             document_type_id=extraction_response.document_type_id,
             operation_id=operation_id,
         )
 
-    @traced(name="documents_create_validation_action_async", run_type="uipath")
-    async def create_validation_action_async(
+    @traced(name="documents_create_validate_extraction_action_async", run_type="uipath")
+    async def create_validate_extraction_action_async(
         self,
         action_title: str,
         action_priority: ActionPriority,
@@ -1142,9 +1410,9 @@ class DocumentsService(FolderContext, BaseService):
         storage_bucket_name: str,
         storage_bucket_directory_path: str,
         extraction_response: ExtractionResponse,
-    ) -> ValidationAction:
-        """Asynchronous version of the [`create_validation_action`][uipath._services.documents_service.DocumentsService.create_validation_action] method."""
-        operation_id = await self._start_validation_async(
+    ) -> ValidateExtractionAction:
+        """Asynchronous version of the [`create_validation_action`][uipath._services.documents_service.DocumentsService.create_validate_extraction_action] method."""
+        operation_id = await self._start_extraction_validation_async(
             project_id=extraction_response.project_id,
             tag=extraction_response.tag,
             document_type_id=extraction_response.document_type_id,
@@ -1157,46 +1425,42 @@ class DocumentsService(FolderContext, BaseService):
             extraction_response=extraction_response,
         )
 
-        return await self._wait_for_create_validation_action_async(
+        return await self._wait_for_create_validate_extraction_action_async(
             project_id=extraction_response.project_id,
+            project_type=extraction_response.project_type,
             tag=extraction_response.tag,
             document_type_id=extraction_response.document_type_id,
             operation_id=operation_id,
         )
 
-    @traced(name="documents_get_validation_result", run_type="uipath")
-    def get_validation_result(
-        self, validation_action: ValidationAction
-    ) -> ValidatedResult:
-        """Get the result of a validation action.
+    @traced(name="documents_get_validate_classification_result", run_type="uipath")
+    def get_validate_classification_result(
+        self, validation_action: ValidateClassificationAction
+    ) -> List[ClassificationResult]:
+        """Get the result of a validate classification action.
 
         Note:
             This method will block until the validation action is completed, meaning the user has completed the validation in UiPath Action Center.
 
         Args:
-            validation_action (ValidationAction): The validation action to get the result for, typically obtained from the [`create_validation_action`][uipath._services.documents_service.DocumentsService.create_validation_action] method.
+            validation_action (ValidateClassificationAction): The validation action to get the result for, typically obtained from the [`create_validate_classification_action`][uipath._services.documents_service.DocumentsService.create_validate_classification_action] method.
 
         Returns:
-            ValidatedResult: The result of the validation action.
+            List[ClassificationResult]: The validated classification results.
 
         Examples:
             ```python
-            validated_result = service.get_validation_result(validation_action)
+            validated_results = service.get_validate_classification_result(validate_classification_action)
             ```
         """
 
         def result_getter() -> Tuple[str, None, Any]:
-            result = self._get_validation_result(
+            result = self._get_classification_validation_result(
                 project_id=validation_action.project_id,
                 tag=validation_action.tag,
-                document_type_id=validation_action.document_type_id,
                 operation_id=validation_action.operation_id,
             )
-            return (
-                result["result"]["actionStatus"],
-                None,
-                result["result"].get("validatedExtractionResults", None),
-            )
+            return (result["result"]["actionStatus"], None, result["result"])
 
         response = self._wait_for_operation(
             result_getter=result_getter,
@@ -1204,31 +1468,131 @@ class DocumentsService(FolderContext, BaseService):
             success_status="Completed",
         )
 
-        return ValidatedResult.model_validate(response)
+        classification_results = []
+        for cr in response["validatedClassificationResults"]:
+            cr["ProjectId"] = validation_action.project_id
+            cr["Tag"] = validation_action.tag
+            classification_results.append(ClassificationResult.model_validate(cr))
 
-    @traced(name="documents_get_validation_result_async", run_type="uipath")
-    async def get_validation_result_async(
-        self, validation_action: ValidationAction
-    ) -> ValidatedResult:
-        """Asynchronous version of the [`get_validation_result`][uipath._services.documents_service.DocumentsService.get_validation_result] method."""
+        return classification_results
+
+    @traced(
+        name="documents_get_validate_classification_result_async", run_type="uipath"
+    )
+    async def get_validate_classification_result_async(
+        self, validation_action: ValidateClassificationAction
+    ) -> List[ClassificationResult]:
+        """Get the result of a validate classification action.
+
+        Note:
+            This method will block until the validation action is completed, meaning the user has completed the validation in UiPath Action Center.
+
+        Args:
+            validation_action (ValidateClassificationAction): The validation action to get the result for, typically obtained from the [`create_validate_classification_action`][uipath._services.documents_service.DocumentsService.create_validate_classification_action] method.
+
+        Returns:
+            List[ClassificationResult]: The validated classification results.
+
+        Examples:
+            ```python
+            validated_results = service.get_validate_classification_result(validate_classification_action)
+            ```
+        """
 
         async def result_getter() -> Tuple[str, None, Any]:
-            result = await self._get_validation_result_async(
+            result = await self._get_classification_validation_result_async(
                 project_id=validation_action.project_id,
                 tag=validation_action.tag,
-                document_type_id=validation_action.document_type_id,
                 operation_id=validation_action.operation_id,
             )
-            return (
-                result["result"]["actionStatus"],
-                None,
-                result["result"].get("validatedExtractionResults", None),
-            )
+            return (result["result"]["actionStatus"], None, result["result"])
 
         response = await self._wait_for_operation_async(
             result_getter=result_getter,
             wait_statuses=["Unassigned", "Pending"],
             success_status="Completed",
         )
+        classification_results = []
+        for cr in response["validatedClassificationResults"]:
+            cr["ProjectId"] = validation_action.project_id
+            cr["Tag"] = validation_action.tag
+            classification_results.append(ClassificationResult.model_validate(cr))
 
-        return ValidatedResult.model_validate(response)
+        return classification_results
+
+    @traced(name="documents_get_validate_extraction_result", run_type="uipath")
+    def get_validate_extraction_result(
+        self, validation_action: ValidateExtractionAction
+    ) -> Union[ExtractionResponse, ExtractionResponseIXP]:
+        """Get the result of a validate extraction action.
+
+        Note:
+            This method will block until the validation action is completed, meaning the user has completed the validation in UiPath Action Center.
+
+        Args:
+            validation_action (ValidateClassificationAction): The validation action to get the result for, typically obtained from the [`create_validate_extraction_action`][uipath._services.documents_service.DocumentsService.create_validate_extraction_action] method.
+
+        Returns:
+            Union[ExtractionResponse, ExtractionResponseIXP]: The validated extraction response.
+
+        Examples:
+            ```python
+            validated_result = service.get_validate_extraction_result(validate_extraction_action)
+            ```
+        """
+
+        def result_getter() -> Tuple[str, None, Any]:
+            result = self._get_extraction_validation_result(
+                project_id=validation_action.project_id,
+                tag=validation_action.tag,
+                document_type_id=validation_action.document_type_id,
+                operation_id=validation_action.operation_id,
+            )
+            return (result["result"]["actionStatus"], None, result["result"])
+
+        response = self._wait_for_operation(
+            result_getter=result_getter,
+            wait_statuses=["Unassigned", "Pending"],
+            success_status="Completed",
+        )
+        response["extractionResult"] = response.pop("validatedExtractionResults")
+        response["projectId"] = validation_action.project_id
+        response["tag"] = validation_action.tag
+        response["documentTypeId"] = validation_action.document_type_id
+        response["projectType"] = validation_action.project_type
+
+        if validation_action.project_type == ProjectType.IXP:
+            return ExtractionResponseIXP.model_validate(response)
+
+        return ExtractionResponse.model_validate(response)
+
+    @traced(name="documents_get_validate_extraction_result_async", run_type="uipath")
+    async def get_validate_extraction_result_async(
+        self, validation_action: ValidateExtractionAction
+    ) -> Union[ExtractionResponse, ExtractionResponseIXP]:
+        """Asynchronous version of the [`get_validation_result`][uipath._services.documents_service.DocumentsService.get_validate_extraction_result] method."""
+
+        async def result_getter() -> Tuple[str, None, Any]:
+            result = await self._get_extraction_validation_result_async(
+                project_id=validation_action.project_id,
+                tag=validation_action.tag,
+                document_type_id=validation_action.document_type_id,
+                operation_id=validation_action.operation_id,
+            )
+            return (result["result"]["actionStatus"], None, result["result"])
+
+        response = await self._wait_for_operation_async(
+            result_getter=result_getter,
+            wait_statuses=["Unassigned", "Pending"],
+            success_status="Completed",
+        )
+        response["extractionResult"] = response.pop("validatedExtractionResults")
+        response["projectId"] = validation_action.project_id
+        response["tag"] = validation_action.tag
+        response["documentTypeId"] = validation_action.document_type_id
+        response["projectType"] = validation_action.project_type
+
+        if validation_action.project_type == ProjectType.IXP:
+            return ExtractionResponseIXP.model_validate(response)
+
+        return ExtractionResponse.model_validate(response)
