@@ -1,8 +1,10 @@
 from enum import Enum
-from typing import List, Optional
+from typing import IO, List, Optional, Union
 
 from pydantic import BaseModel, ConfigDict, Field
 
+FileContent = Union[IO[bytes], bytes, str]
+
 
 class FieldType(str, Enum):
     TEXT = "Text"
@@ -47,10 +49,10 @@ class FieldValueProjection(BaseModel):
 
     id: str
     name: str
-    value: str
-    unformatted_value: str = Field(alias="unformattedValue")
-    confidence: float
-    ocr_confidence: float = Field(alias="ocrConfidence")
+    value: Optional[str]
+    unformatted_value: Optional[str] = Field(alias="unformattedValue")
+    confidence: Optional[float]
+    ocr_confidence: Optional[float] = Field(alias="ocrConfidence")
     type: FieldType
 
 
@@ -98,6 +100,7 @@ class ExtractionResponse(BaseModel):
 
     extraction_result: ExtractionResult = Field(alias="extractionResult")
     project_id: str = Field(alias="projectId")
+    project_type: ProjectType = Field(alias="projectType")
     tag: str
     document_type_id: str = Field(alias="documentTypeId")
 
@@ -131,26 +134,17 @@ class ValidationAction(BaseModel):
     action_data: dict = Field(alias="actionData")  # type: ignore
     action_status: str = Field(alias="actionStatus")
     project_id: str = Field(alias="projectId")
+    project_type: ProjectType = Field(alias="projectType")
     tag: str
-    document_type_id: str = Field(alias="documentTypeId")
     operation_id: str = Field(alias="operationId")
 
 
-class ValidatedResult(BaseModel):
-    """A model representing the result of a validation action.
+class ValidateClassificationAction(ValidationAction):
+    pass
 
-    Attributes:
-        document_id (str): The ID of the validated document.
-        results_document (dict): The validated results document.
-    """
 
-    model_config = ConfigDict(
-        serialize_by_alias=True,
-        validate_by_alias=True,
-    )
-
-    document_id: str = Field(alias="DocumentId")
-    results_document: dict = Field(alias="ResultsDocument")  # type: ignore
+class ValidateExtractionAction(ValidationAction):
+    document_type_id: str = Field(alias="documentTypeId")
 
 
 class Reference(BaseModel):
@@ -204,6 +198,7 @@ class ClassificationResult(BaseModel):
     document_bounds: DocumentBounds = Field(alias="DocumentBounds")
     classifier_name: str = Field(alias="ClassifierName")
     project_id: str = Field(alias="ProjectId")
+    tag: str = Field(alias="Tag")
 
 
 class ClassificationResponse(BaseModel):
