@@ -14,7 +14,8 @@ from uipath.models.documents import (
     ClassificationResult,
     ExtractionResponse,
     ProjectType,
-    ValidationAction,
+    ValidateClassificationAction,
+    ValidateExtractionAction,
 )
 
 
@@ -55,15 +56,6 @@ def create_validation_action_response(documents_tests_data_path: Path) -> dict:
         return json.load(f)
 
 
-@pytest.fixture
-def validated_result(documents_tests_data_path: Path) -> dict:  # type: ignore
-    with open(
-        documents_tests_data_path / "validated_result.json",
-        "r",
-    ) as f:
-        return json.load(f)
-
-
 class TestDocumentsService:
     @pytest.mark.parametrize("mode", ["sync", "async"])
     @pytest.mark.parametrize(
@@ -119,6 +111,7 @@ class TestDocumentsService:
         document_id = str(uuid4())
         document_type_id = str(uuid4())
         classification_response["classificationResults"][0]["ProjectId"] = project_id
+        classification_response["classificationResults"][0]["Tag"] = "Production"
         classification_response["classificationResults"][0]["DocumentId"] = document_id
         classification_response["classificationResults"][0]["DocumentTypeId"] = (
             document_type_id
@@ -162,15 +155,14 @@ class TestDocumentsService:
         # ACT
         if mode == "async":
             response = await service.extract_async(
-                tag="Production", classification_result=classification_result
+                classification_result=classification_result
             )
         else:
-            response = service.extract(
-                tag="Production", classification_result=classification_result
-            )
+            response = service.extract(classification_result=classification_result)
 
         # ASSERT
         modern_extraction_response["projectId"] = project_id
+        modern_extraction_response["projectType"] = ProjectType.MODERN
         modern_extraction_response["tag"] = "Production"
         modern_extraction_response["documentTypeId"] = document_type_id
         assert response.model_dump() == modern_extraction_response
@@ -268,6 +260,7 @@ class TestDocumentsService:
 
         # ASSERT
         classification_response["classificationResults"][0]["ProjectId"] = project_id
+        classification_response["classificationResults"][0]["Tag"] = "Production"
         assert (
             response[0].model_dump()
             == classification_response["classificationResults"][0]
@@ -276,7 +269,7 @@ class TestDocumentsService:
     @pytest.mark.parametrize("mode", ["sync", "async"])
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
-        "project_name,file,file_path,classification_result,project_type,document_type_name, error",
+        "tag,project_name,file,file_path,classification_result,project_type,document_type_name, error",
         [
             (
                 None,
@@ -285,9 +278,11 @@ class TestDocumentsService:
                 None,
                 None,
                 None,
+                None,
                 "`classification_result` must be provided",
             ),
             (
+                "live",
                 "TestProject",
                 None,
                 None,
@@ -297,6 +292,7 @@ class TestDocumentsService:
                 "`project_type` must be provided",
             ),
             (
+                "live",
                 "TestProject",
                 None,
                 None,
@@ -306,6 +302,7 @@ class TestDocumentsService:
                 "Exactly one of `file, file_path` must be provided",
             ),
             (
+                "live",
                 "TestProject",
                 b"something",
                 None,
@@ -315,6 +312,7 @@ class TestDocumentsService:
                 "`document_type_name` must be provided",
             ),
             (
+                "live",
                 "TestProject",
                 b"something",
                 None,
@@ -323,12 +321,23 @@ class TestDocumentsService:
                 "dummy doctype",
                 "`classification_result` must not be provided",
             ),
+            (
+                None,
+                "TestProject",
+                b"something",
+                None,
+                None,
+                ProjectType.MODERN,
+                "dummy doctype",
+                "`tag` must be provided",
+            ),
         ],
     )
     async def test_extract_with_invalid_parameters(
         self,
         service: DocumentsService,
         mode: str,
+        tag,
         project_name,
         file,
         file_path,
@@ -341,7 +350,7 @@ class TestDocumentsService:
         with pytest.raises(ValueError, match=error):
             if mode == "async":
                 await service.extract_async(
-                    tag="live",
+                    tag=tag,
                     project_name=project_name,
                     project_type=project_type,
                     file=file,
@@ -351,7 +360,7 @@ class TestDocumentsService:
                 )
             else:
                 service.extract(
-                    tag="live",
+                    tag=tag,
                     project_name=project_name,
                     project_type=project_type,
                     file=file,
@@ -476,6 +485,7 @@ class TestDocumentsService:
         # ASSERT
         expected_response = ixp_extraction_response
         expected_response["projectId"] = project_id
+        expected_response["projectType"] = ProjectType.IXP.value
         expected_response["tag"] = "live"
         expected_response["documentTypeId"] = str(UUID(int=0))
         assert response.model_dump() == expected_response
@@ -603,6 +613,7 @@ class TestDocumentsService:
         # ASSERT
         expected_response = modern_extraction_response
         expected_response["projectId"] = project_id
+        expected_response["projectType"] = ProjectType.MODERN.value
         expected_response["tag"] = "Production"
         expected_response["documentTypeId"] = document_type_id
         assert response.model_dump() == expected_response
@@ -824,7 +835,125 @@ class TestDocumentsService:
 
     @pytest.mark.parametrize("mode", ["sync", "async"])
     @pytest.mark.asyncio
-    async def test_create_validation_action(
+    async def test_create_validate_classification_action(
+        self,
+        httpx_mock: HTTPXMock,
+        service: DocumentsService,
+        base_url: str,
+        org: str,
+        tenant: str,
+        classification_response: dict,  # type: ignore
+        create_validation_action_response: dict,  # type: ignore
+        mode: str,
+    ):
+        # ARRANGE
+        project_id = str(uuid4())
+        operation_id = str(uuid4())
+        tag = "Production"
+        action_title = "TestAction"
+        action_priority = ActionPriority.MEDIUM
+        action_catalog = "TestCatalog"
+        action_folder = "TestFolder"
+        storage_bucket_name = "TestBucket"
+        storage_bucket_directory_path = "Test/Directory/Path"
+
+        classification_result = classification_response["classificationResults"][0]
+        classification_result["ProjectId"] = project_id
+        classification_result["Tag"] = tag
+        classification_result = ClassificationResult.model_validate(
+            classification_result
+        )
+
+        httpx_mock.add_response(
+            url=f"{base_url}{org}{tenant}/du_/api/framework/projects/{project_id}/{tag}/classifiers/validation/start?api-version=1.1",
+            status_code=200,
+            match_headers={"X-UiPath-Internal-ConsumptionSourceType": "CodedAgents"},
+            match_json={
+                "actionTitle": action_title,
+                "actionPriority": action_priority,
+                "actionCatalog": action_catalog,
+                "actionFolder": action_folder,
+                "storageBucketName": storage_bucket_name,
+                "storageBucketDirectoryPath": storage_bucket_directory_path,
+                "classificationResults": [
+                    classification_result.model_dump(),
+                ],
+                "documentId": classification_result.document_id,
+            },
+            json={"operationId": operation_id},
+        )
+
+        httpx_mock.add_response(
+            url=f"{base_url}{org}{tenant}/du_/api/framework/projects/{project_id}/{tag}/classifiers/validation/result/{operation_id}?api-version=1.1",
+            status_code=200,
+            match_headers={"X-UiPath-Internal-ConsumptionSourceType": "CodedAgents"},
+            json={"status": "Succeeded", "result": create_validation_action_response},
+        )
+
+        # ACT
+        if mode == "async":
+            response = await service.create_validate_classification_action_async(
+                action_title=action_title,
+                action_priority=action_priority,
+                action_catalog=action_catalog,
+                action_folder=action_folder,
+                storage_bucket_name=storage_bucket_name,
+                storage_bucket_directory_path=storage_bucket_directory_path,
+                classification_results=[classification_result],
+            )
+        else:
+            response = service.create_validate_classification_action(
+                action_title=action_title,
+                action_priority=action_priority,
+                action_catalog=action_catalog,
+                action_folder=action_folder,
+                storage_bucket_name=storage_bucket_name,
+                storage_bucket_directory_path=storage_bucket_directory_path,
+                classification_results=[classification_result],
+            )
+        # ASSERT
+        create_validation_action_response["projectId"] = project_id
+        create_validation_action_response["projectType"] = ProjectType.MODERN.value
+        create_validation_action_response["tag"] = tag
+        create_validation_action_response["operationId"] = operation_id
+        assert response.model_dump() == create_validation_action_response
+
+    @pytest.mark.parametrize("mode", ["sync", "async"])
+    @pytest.mark.asyncio
+    async def test_create_validate_classification_action_with_empty_classification_results(
+        self,
+        service: DocumentsService,
+        mode: str,
+    ):
+        # ACT & ASSERT
+        with pytest.raises(
+            ValueError,
+            match="`classification_results` must not be empty",
+        ):
+            if mode == "async":
+                await service.create_validate_classification_action_async(
+                    action_title="TestAction",
+                    action_priority=ActionPriority.MEDIUM,
+                    action_catalog="TestCatalog",
+                    action_folder="TestFolder",
+                    storage_bucket_name="TestBucket",
+                    storage_bucket_directory_path="Test/Directory/Path",
+                    classification_results=[],
+                )
+            else:
+                service.create_validate_classification_action(
+                    action_title="TestAction",
+                    action_priority=ActionPriority.MEDIUM,
+                    action_catalog="TestCatalog",
+                    action_folder="TestFolder",
+                    storage_bucket_name="TestBucket",
+                    storage_bucket_directory_path="Test/Directory/Path",
+                    classification_results=[],
+                )
+
+    @pytest.mark.parametrize("mode", ["sync", "async"])
+    @pytest.mark.asyncio
+    async def test_create_validate_extraction_action(
         self,
         httpx_mock: HTTPXMock,
         service: DocumentsService,
@@ -886,12 +1015,13 @@ class TestDocumentsService:
         )
 
         ixp_extraction_response["projectId"] = project_id
+        ixp_extraction_response["projectType"] = ProjectType.IXP.value
         ixp_extraction_response["tag"] = tag
         ixp_extraction_response["documentTypeId"] = document_type_id
 
         # ACT
         if mode == "async":
-            response = await service.create_validation_action_async(
+            response = await service.create_validate_extraction_action_async(
                 action_title=action_title,
                 action_priority=action_priority,
                 action_catalog=action_catalog,
@@ -903,7 +1033,7 @@ class TestDocumentsService:
                 ),
             )
         else:
-            response = service.create_validation_action(
+            response = service.create_validate_extraction_action(
                 action_title=action_title,
                 action_priority=action_priority,
                 action_catalog=action_catalog,
@@ -917,6 +1047,7 @@ class TestDocumentsService:
 
         # ASSERT
         create_validation_action_response["projectId"] = project_id
+        create_validation_action_response["projectType"] = ProjectType.IXP.value
         create_validation_action_response["tag"] = tag
         create_validation_action_response["documentTypeId"] = document_type_id
         create_validation_action_response["operationId"] = operation_id
@@ -924,7 +1055,7 @@ class TestDocumentsService:
 
     @pytest.mark.parametrize("mode", ["sync", "async"])
     @pytest.mark.asyncio
-    async def test_get_validation_result(
+    async def test_get_validate_classification_result(
         self,
         httpx_mock: HTTPXMock,
         base_url: str,
@@ -932,25 +1063,103 @@ class TestDocumentsService:
         tenant: str,
         service: DocumentsService,
         create_validation_action_response: dict,  # type: ignore
-        validated_result: dict,  # type: ignore
+        classification_response: dict,  # type: ignore
         mode: str,
     ):
         # ARRANGE
         project_id = str(uuid4())
         operation_id = str(uuid4())
+
+        create_validation_action_response["actionStatus"] = "Completed"
+        create_validation_action_response["validatedClassificationResults"] = (
+            classification_response["classificationResults"]
+        )
+
+        httpx_mock.add_response(
+            url=f"{base_url}{org}{tenant}/du_/api/framework/projects/{project_id}/Production/classifiers/validation/result/{operation_id}?api-version=1.1",
+            status_code=200,
+            match_headers={"X-UiPath-Internal-ConsumptionSourceType": "CodedAgents"},
+            json={"status": "Succeeded", "result": create_validation_action_response},
+        )
+
+        create_validation_action_response["projectId"] = project_id
+        create_validation_action_response["projectType"] = ProjectType.MODERN.value
+        create_validation_action_response["tag"] = "Production"
+        create_validation_action_response["operationId"] = operation_id
+
+        # ACT
+        if mode == "async":
+            results = await service.get_validate_classification_result_async(
+                validation_action=ValidateClassificationAction.model_validate(
+                    create_validation_action_response
+                )
+            )
+        else:
+            results = service.get_validate_classification_result(
+                validation_action=ValidateClassificationAction.model_validate(
+                    create_validation_action_response
+                )
+            )
+
+        # ASSERT
+        classification_response["classificationResults"][0]["ProjectId"] = project_id
+        classification_response["classificationResults"][0]["Tag"] = "Production"
+        assert (
+            results[0].model_dump()
+            == classification_response["classificationResults"][0]
+        )
+
+    @pytest.mark.parametrize("mode", ["sync", "async"])
+    @pytest.mark.parametrize(
+        "project_type,tag,extraction_response_fixture",
+        [
+            (ProjectType.MODERN, "Production", "modern_extraction_response"),
+            (ProjectType.IXP, "live", "ixp_extraction_response"),
+        ],
+    )
+    @pytest.mark.asyncio
+    async def test_get_validate_extraction_result(
+        self,
+        httpx_mock: HTTPXMock,
+        base_url: str,
+        org: str,
+        tenant: str,
+        service: DocumentsService,
+        create_validation_action_response: dict,  # type: ignore
+        modern_extraction_response: dict,  # type: ignore
+        ixp_extraction_response: dict,  # type: ignore
+        mode: str,
+        project_type: ProjectType,
+        tag: str,
+        extraction_response_fixture: str,
+    ):
+        # ARRANGE
+        project_id = str(uuid4())
+        operation_id = str(uuid4())
         document_type_id = str(UUID(int=0))
 
+        # Select the appropriate extraction response based on the fixture name
+        extraction_response = (
+            modern_extraction_response
+            if extraction_response_fixture == "modern_extraction_response"
+            else ixp_extraction_response
+        )
+
         create_validation_action_response["projectId"] = project_id
-        create_validation_action_response["tag"] = "live"
+        create_validation_action_response["projectType"] = project_type.value
+        create_validation_action_response["tag"] = tag
         create_validation_action_response["documentTypeId"] = document_type_id
         create_validation_action_response["operationId"] = operation_id
         create_validation_action_response["actionStatus"] = "Completed"
         create_validation_action_response["validatedExtractionResults"] = (
-            validated_result
+            extraction_response["extractionResult"]
+        )
+        create_validation_action_response["dataProjection"] = extraction_response.get(
+            "dataProjection", None
         )
 
         httpx_mock.add_response(
-            url=f"{base_url}{org}{tenant}/du_/api/framework/projects/{project_id}/live/document-types/{document_type_id}/validation/result/{operation_id}?api-version=1.1",
+            url=f"{base_url}{org}{tenant}/du_/api/framework/projects/{project_id}/{tag}/document-types/{document_type_id}/validation/result/{operation_id}?api-version=1.1",
             status_code=200,
             match_headers={"X-UiPath-Internal-ConsumptionSourceType": "CodedAgents"},
             json={"status": "Succeeded", "result": create_validation_action_response},
@@ -958,20 +1167,24 @@ class TestDocumentsService:
 
         # ACT
         if mode == "async":
-            response = await service.get_validation_result_async(
-                validation_action=ValidationAction.model_validate(
+            response = await service.get_validate_extraction_result_async(
+                validation_action=ValidateExtractionAction.model_validate(
                     create_validation_action_response
                 )
             )
         else:
-            response = service.get_validation_result(
-                validation_action=ValidationAction.model_validate(
+            response = service.get_validate_extraction_result(
+                validation_action=ValidateExtractionAction.model_validate(
                     create_validation_action_response
                 )
             )
 
         # ASSERT
-        assert response.model_dump() == validated_result
+        extraction_response["projectId"] = project_id
+        extraction_response["projectType"] = project_type
+        extraction_response["tag"] = tag
+        extraction_response["documentTypeId"] = document_type_id
+        assert response.model_dump() == extraction_response
 
     @pytest.mark.parametrize("mode", ["sync", "async"])
     @pytest.mark.asyncio
